"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_container_1 = require("@arkecosystem/core-container");
const command_1 = require("@oclif/command");
const cli_progress_1 = __importDefault(require("cli-progress"));
const utils_1 = require("../utils");
const command_2 = require("./command");
class RestoreCommand extends command_2.BaseCommand {
    async run() {
        // tslint:disable-next-line:no-shadowed-variable
        const { flags } = this.parse(RestoreCommand);
        await utils_1.setUpLite(flags);
        const emitter = core_container_1.app.resolvePlugin("event-emitter");
        const progressBar = new cli_progress_1.default.Bar({
            format: "{bar} {percentage}% | ETA: {eta}s | {value}/{total} | Duration: {duration}s",
        }, cli_progress_1.default.Presets.shades_classic);
        emitter.on("start", data => {
            progressBar.start(data.count, 1);
        });
        emitter.on("progress", data => {
            progressBar.update(data.value);
        });
        emitter.on("complete", data => {
            progressBar.stop();
        });
        await core_container_1.app.resolvePlugin("snapshots").importData(flags);
    }
}
RestoreCommand.description = "import data from specified snapshot";
RestoreCommand.flags = Object.assign({}, command_2.BaseCommand.flags, { blocks: command_1.flags.string({
        description: "blocks to import, corelates to folder name",
        required: true,
    }), codec: command_1.flags.string({
        description: "codec name, default is msg-lite binary",
    }), truncate: command_1.flags.boolean({
        description: "empty all tables before running import",
    }), skipRestartRound: command_1.flags.boolean({
        description: "skip revert to current round",
    }), signatureVerify: command_1.flags.boolean({
        description: "signature verification",
    }) });
exports.RestoreCommand = RestoreCommand;
//# sourceMappingURL=restore.js.map